
/* Generated data (by glib-mkenums) */

#undef GTK_DISABLE_DEPRECATED
#define GTK_ENABLE_BROKEN
#include <thunar-vfs/thunar-vfs.h>
#include <thunar-vfs/thunar-vfs-alias.h>

/* enumerations from "thunar-vfs-info.h" */
GType
thunar_vfs_file_hint_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
	static const GEnumValue values[] = {
	{ THUNAR_VFS_FILE_HINT_ICON, "THUNAR_VFS_FILE_HINT_ICON", "hint-icon" },
	{ THUNAR_VFS_FILE_N_HINTS, "THUNAR_VFS_FILE_N_HINTS", "n-hints" },
	{ 0, NULL, NULL }
	};
	type = g_enum_register_static ("ThunarVfsFileHint", values);
  }
	return type;
}

/* enumerations from "thunar-vfs-interactive-job.h" */
GType
thunar_vfs_interactive_job_response_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
	static const GFlagsValue values[] = {
	{ THUNAR_VFS_INTERACTIVE_JOB_RESPONSE_YES, "THUNAR_VFS_INTERACTIVE_JOB_RESPONSE_YES", "yes" },
	{ THUNAR_VFS_INTERACTIVE_JOB_RESPONSE_YES_ALL, "THUNAR_VFS_INTERACTIVE_JOB_RESPONSE_YES_ALL", "yes-all" },
	{ THUNAR_VFS_INTERACTIVE_JOB_RESPONSE_NO, "THUNAR_VFS_INTERACTIVE_JOB_RESPONSE_NO", "no" },
	{ THUNAR_VFS_INTERACTIVE_JOB_RESPONSE_CANCEL, "THUNAR_VFS_INTERACTIVE_JOB_RESPONSE_CANCEL", "cancel" },
	{ 0, NULL, NULL }
	};
	type = g_flags_register_static ("ThunarVfsInteractiveJobResponse", values);
  }
	return type;
}

/* enumerations from "thunar-vfs-mime-application.h" */
GType
thunar_vfs_mime_application_error_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
	static const GEnumValue values[] = {
	{ THUNAR_VFS_MIME_APPLICATION_ERROR_LOCAL_FILES_ONLY, "THUNAR_VFS_MIME_APPLICATION_ERROR_LOCAL_FILES_ONLY", "only" },
	{ 0, NULL, NULL }
	};
	type = g_enum_register_static ("ThunarVfsMimeApplicationError", values);
  }
	return type;
}
GType
thunar_vfs_mime_application_flags_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
	static const GFlagsValue values[] = {
	{ THUNAR_VFS_MIME_APPLICATION_HIDDEN, "THUNAR_VFS_MIME_APPLICATION_HIDDEN", "hidden" },
	{ THUNAR_VFS_MIME_APPLICATION_REQUIRES_TERMINAL, "THUNAR_VFS_MIME_APPLICATION_REQUIRES_TERMINAL", "requires-terminal" },
	{ THUNAR_VFS_MIME_APPLICATION_SUPPORTS_STARTUP_NOTIFY, "THUNAR_VFS_MIME_APPLICATION_SUPPORTS_STARTUP_NOTIFY", "supports-startup-notify" },
	{ THUNAR_VFS_MIME_APPLICATION_SUPPORTS_MULTI, "THUNAR_VFS_MIME_APPLICATION_SUPPORTS_MULTI", "supports-multi" },
	{ 0, NULL, NULL }
	};
	type = g_flags_register_static ("ThunarVfsMimeApplicationFlags", values);
  }
	return type;
}

/* enumerations from "thunar-vfs-monitor.h" */
GType
thunar_vfs_monitor_event_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
	static const GEnumValue values[] = {
	{ THUNAR_VFS_MONITOR_EVENT_CHANGED, "THUNAR_VFS_MONITOR_EVENT_CHANGED", "changed" },
	{ THUNAR_VFS_MONITOR_EVENT_CREATED, "THUNAR_VFS_MONITOR_EVENT_CREATED", "created" },
	{ THUNAR_VFS_MONITOR_EVENT_DELETED, "THUNAR_VFS_MONITOR_EVENT_DELETED", "deleted" },
	{ 0, NULL, NULL }
	};
	type = g_enum_register_static ("ThunarVfsMonitorEvent", values);
  }
	return type;
}

/* enumerations from "thunar-vfs-types.h" */
GType
thunar_vfs_file_type_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
	static const GEnumValue values[] = {
	{ THUNAR_VFS_FILE_TYPE_SOCKET, "THUNAR_VFS_FILE_TYPE_SOCKET", "socket" },
	{ THUNAR_VFS_FILE_TYPE_SYMLINK, "THUNAR_VFS_FILE_TYPE_SYMLINK", "symlink" },
	{ THUNAR_VFS_FILE_TYPE_REGULAR, "THUNAR_VFS_FILE_TYPE_REGULAR", "regular" },
	{ THUNAR_VFS_FILE_TYPE_BLOCKDEV, "THUNAR_VFS_FILE_TYPE_BLOCKDEV", "blockdev" },
	{ THUNAR_VFS_FILE_TYPE_DIRECTORY, "THUNAR_VFS_FILE_TYPE_DIRECTORY", "directory" },
	{ THUNAR_VFS_FILE_TYPE_CHARDEV, "THUNAR_VFS_FILE_TYPE_CHARDEV", "chardev" },
	{ THUNAR_VFS_FILE_TYPE_FIFO, "THUNAR_VFS_FILE_TYPE_FIFO", "fifo" },
	{ THUNAR_VFS_FILE_TYPE_UNKNOWN, "THUNAR_VFS_FILE_TYPE_UNKNOWN", "unknown" },
	{ 0, NULL, NULL }
	};
	type = g_enum_register_static ("ThunarVfsFileType", values);
  }
	return type;
}
GType
thunar_vfs_file_mode_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
	static const GFlagsValue values[] = {
	{ THUNAR_VFS_FILE_MODE_SUID, "THUNAR_VFS_FILE_MODE_SUID", "suid" },
	{ THUNAR_VFS_FILE_MODE_SGID, "THUNAR_VFS_FILE_MODE_SGID", "sgid" },
	{ THUNAR_VFS_FILE_MODE_STICKY, "THUNAR_VFS_FILE_MODE_STICKY", "sticky" },
	{ THUNAR_VFS_FILE_MODE_USR_ALL, "THUNAR_VFS_FILE_MODE_USR_ALL", "usr-all" },
	{ THUNAR_VFS_FILE_MODE_USR_READ, "THUNAR_VFS_FILE_MODE_USR_READ", "usr-read" },
	{ THUNAR_VFS_FILE_MODE_USR_WRITE, "THUNAR_VFS_FILE_MODE_USR_WRITE", "usr-write" },
	{ THUNAR_VFS_FILE_MODE_USR_EXEC, "THUNAR_VFS_FILE_MODE_USR_EXEC", "usr-exec" },
	{ THUNAR_VFS_FILE_MODE_GRP_ALL, "THUNAR_VFS_FILE_MODE_GRP_ALL", "grp-all" },
	{ THUNAR_VFS_FILE_MODE_GRP_READ, "THUNAR_VFS_FILE_MODE_GRP_READ", "grp-read" },
	{ THUNAR_VFS_FILE_MODE_GRP_WRITE, "THUNAR_VFS_FILE_MODE_GRP_WRITE", "grp-write" },
	{ THUNAR_VFS_FILE_MODE_GRP_EXEC, "THUNAR_VFS_FILE_MODE_GRP_EXEC", "grp-exec" },
	{ THUNAR_VFS_FILE_MODE_OTH_ALL, "THUNAR_VFS_FILE_MODE_OTH_ALL", "oth-all" },
	{ THUNAR_VFS_FILE_MODE_OTH_READ, "THUNAR_VFS_FILE_MODE_OTH_READ", "oth-read" },
	{ THUNAR_VFS_FILE_MODE_OTH_WRITE, "THUNAR_VFS_FILE_MODE_OTH_WRITE", "oth-write" },
	{ THUNAR_VFS_FILE_MODE_OTH_EXEC, "THUNAR_VFS_FILE_MODE_OTH_EXEC", "oth-exec" },
	{ 0, NULL, NULL }
	};
	type = g_flags_register_static ("ThunarVfsFileMode", values);
  }
	return type;
}
GType
thunar_vfs_file_flags_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
	static const GFlagsValue values[] = {
	{ THUNAR_VFS_FILE_FLAGS_NONE, "THUNAR_VFS_FILE_FLAGS_NONE", "none" },
	{ THUNAR_VFS_FILE_FLAGS_SYMLINK, "THUNAR_VFS_FILE_FLAGS_SYMLINK", "symlink" },
	{ THUNAR_VFS_FILE_FLAGS_EXECUTABLE, "THUNAR_VFS_FILE_FLAGS_EXECUTABLE", "executable" },
	{ 0, NULL, NULL }
	};
	type = g_flags_register_static ("ThunarVfsFileFlags", values);
  }
	return type;
}

/* enumerations from "thunar-vfs-volume.h" */
GType
thunar_vfs_volume_kind_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
	static const GEnumValue values[] = {
	{ THUNAR_VFS_VOLUME_KIND_UNKNOWN, "THUNAR_VFS_VOLUME_KIND_UNKNOWN", "unknown" },
	{ THUNAR_VFS_VOLUME_KIND_CDROM, "THUNAR_VFS_VOLUME_KIND_CDROM", "cdrom" },
	{ THUNAR_VFS_VOLUME_KIND_DVD, "THUNAR_VFS_VOLUME_KIND_DVD", "dvd" },
	{ THUNAR_VFS_VOLUME_KIND_FLOPPY, "THUNAR_VFS_VOLUME_KIND_FLOPPY", "floppy" },
	{ THUNAR_VFS_VOLUME_KIND_HARDDISK, "THUNAR_VFS_VOLUME_KIND_HARDDISK", "harddisk" },
	{ THUNAR_VFS_VOLUME_KIND_USBSTICK, "THUNAR_VFS_VOLUME_KIND_USBSTICK", "usbstick" },
	{ 0, NULL, NULL }
	};
	type = g_enum_register_static ("ThunarVfsVolumeKind", values);
  }
	return type;
}
GType
thunar_vfs_volume_status_get_type (void)
{
	static GType type = 0;
	if (type == 0) {
	static const GFlagsValue values[] = {
	{ THUNAR_VFS_VOLUME_STATUS_MOUNTED, "THUNAR_VFS_VOLUME_STATUS_MOUNTED", "mounted" },
	{ THUNAR_VFS_VOLUME_STATUS_PRESENT, "THUNAR_VFS_VOLUME_STATUS_PRESENT", "present" },
	{ 0, NULL, NULL }
	};
	type = g_flags_register_static ("ThunarVfsVolumeStatus", values);
  }
	return type;
}

#define __THUNAR_VFS_ENUM_TYPES_C__
#include "thunar-vfs-aliasdef.c"

/* Generated data ends here */

